{% extends "layout_2_col.html" %}
{% load i18n %}

{% block navigation %}
    {% include "partials/nav_alternate.html" %}
{% endblock %}

{% block column_left %}
{% endblock %}

{% block headertext %}
{% trans "Welcome!" %}
{% endblock %}

{% block content %}
{% endblock content %}
