<div class="navbar nav-profile">
    <div class="navbar-inner">
        <div class="container">

            <a class="btn btn-navbar" data-toggle="collapse" data-target=".profile-collapse">
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
            </a>

            <span class="brand visible-phone" href="#">Account</span>

            <div class="nav-collapse profile-collapse">
                <ul class="nav nav-tabs">
                    <li class="{{ profile }}"><a href="{% url customer:summary %}#profile" >Profile</a></li>
                    <li class="{{ order_history }}"><a href="{% url customer:summary %}#orders"  >Order History</a></li>
                    <li class="{{ address_book }}"><a href="{% url customer:summary %}#addresses" >Address Book</a></li>
                    <li class="{{ email_history }}"><a href="{% url customer:summary %}#emails" >Email History</a></li>
                    <li class="{{ alerts }}"><a href="{% url customer:summary %}#alerts" >Alerts</a></li>
                </ul>
            </div>

        </div>
    </div>
</div>
